==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_hr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hr" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disk je zauzet, ne mogu sada izbaciti</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Uređaj je zauzet, ne mogu sada izbaciti</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Uređaj je zauzet, ne mogu sada ukloniti</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Nepoznato</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Uređaj nije sigurno uklonjen</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Klikni &quot;Sigurno ukloni&quot; i odspoji ga slijedeći put</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">Uređaj je zauzet, ne mogu sada izbaciti</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">Uređaj je zauzet, ne mogu sada ukloniti</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Ne mogu odmontirati uređaj</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Disk je montirao korisnik &quot;%1&quot;, vi ga ne možete odmontirati.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Ne mogu naći montirani uređaj</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Diskovi</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otvori</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Izbaci sve</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Uređaj je sigurno uklonjen</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Pristup odbijen</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Nemate dozvole za pristup ovoj mapi</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdi</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.8.1.orig.tar.xz: dde-file-manager-5.8.1/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_hr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hr">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Disk je zauzet, ne mogu sada odmontirati</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disk je zauzet, ne mogu sada izbaciti</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Uređaj je zauzet, ne mogu sada izbaciti</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Uređaj je zauzet, ne mogu sada ukloniti</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Nepoznato</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-upravitelj-datotekama</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Uređaj nije sigurno uklonjen</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Klikni &quot;Sigurno ukloni&quot; i odspoji ga slijedeći put</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Ne mogu odmontirati uređaj</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Disk je montirao korisnik &quot;%1&quot;, vi ga ne možete odmontirati.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Ne mogu naći montirani uređaj</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Diskovi</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otvori</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Izbaci sve</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Uređaj je sigurno uklonjen</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Pristup odbijen</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Nemate dozvole za pristup ovoj mapi</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Skeniram uređaj, prestati?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Potvrdi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Zaustavi</translation>
    </message>
</context>
</TS>
